import type { CfDeployConfigPromptOptions, CfDeployConfigQuestions, CfSystemChoice, CfDeployConfigAnswers } from './types';
import { promptNames } from './types';
import type { InquirerAdapter } from '@sap-ux/inquirer-common';
import type { Logger } from '@sap-ux/logger';
/**
 * Retrieves Cloud Foundry deployment configuration prompts.
 *
 * This function returns a list of cf deployment questions based on the provided application root and prompt options.
 *
 * @param {CfDeployConfigPromptOptions} promptOptions - The configuration options for prompting during cf target deployment.
 * @param logger - The logger instance to use for logging.
 * @returns {Promise<CfDeployConfigQuestions[]>} A promise that resolves to an array of questions for cf target prompting.
 */
declare function getPrompts(promptOptions: CfDeployConfigPromptOptions, logger?: Logger): Promise<CfDeployConfigQuestions[]>;
/**
 * Prompt for cf inquirer inputs.
 *
 * @param adapter - optionally provide references to a calling inquirer instance, this supports integration to Yeoman generators, for example
 * @param promptOptions - options that can control some of the prompt behavior. See {@link CfDeployConfigPromptOptions} for details
 * @param logger - logger instance to use for logging
 * @returns the prompt answers
 */
declare function prompt(adapter: InquirerAdapter, promptOptions: CfDeployConfigPromptOptions, logger?: Logger): Promise<CfDeployConfigAnswers>;
export { getPrompts, CfDeployConfigPromptOptions, CfSystemChoice, promptNames, prompt };
//# sourceMappingURL=index.d.ts.map