"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateDestinationQuestion = validateDestinationQuestion;
const i18n_1 = require("../i18n");
/**
 *
 * @param input The input string to check for emptiness.
 * @returns returns true if the input string is not empty, otherwise false.
 */
function isNotEmpty(input) {
    return !!input?.trim();
}
/**
 * Validates the input string for the following:
 * - It must not be empty after trimming whitespace.
 * - It must contain only alphanumeric characters, underscores, or dashes.
 * - It must not exceed 200 characters.
 *
 * @param {string} input - The input string to validate.
 * @returns {boolean|string} `true` if the input is valid, otherwise an error message.
 */
function validateInput(input) {
    if (!isNotEmpty(input)) {
        return (0, i18n_1.t)('errors.emptyDestinationNameError');
    }
    const result = /^[a-z0-9_-]+$/i.test(input);
    if (!result) {
        return (0, i18n_1.t)('errors.destinationNameError');
    }
    if (input.length > 200) {
        return (0, i18n_1.t)('errors.destinationNameLengthError');
    }
    return true;
}
/**
 * Validates the destination name or input string. If `allowEmptyChoice` is true,
 * the validation will pass immediately. Otherwise, the input will be validated
 * against rules (non-empty, valid characters, length check).
 *
 * @param {string} input - The destination name or input string to validate.
 * @param {boolean} allowEmptyChoice - Whether to allow an empty input as a valid choice.
 * @returns {boolean|string} `true` if the input is valid or empty choices are allowed, otherwise an error message.
 */
function validateDestinationQuestion(input, allowEmptyChoice = false) {
    if (allowEmptyChoice) {
        return true;
    }
    return typeof input === 'string' ? validateInput(input) : true;
}
//# sourceMappingURL=validators.js.map